@@ -20,6 +20,7 @@ from lollypop.tagreader import TagReader
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
 from lollypop.utils import escape, is_readonly
+from lollypop.lio import Lio
 
 
 class AlbumArt(BaseArt, TagReader):
@@ -51,7 +52,7 @@ class AlbumArt(BaseArt, TagReader):
             cache_path_jpg = "%s/%s_%s.jpg" % (self._CACHE_PATH,
                                                filename,
                                                size)
-            f = Gio.File.new_for_path(cache_path_jpg)
+            f = Lio.File.new_for_path(cache_path_jpg)
             if f.query_exists():
                 return cache_path_jpg
             else:
@@ -88,7 +89,7 @@ class AlbumArt(BaseArt, TagReader):
                 album.uri + "/" + filename
             ]
             for uri in uris:
-                f = Gio.File.new_for_uri(uri)
+                f = Lio.File.new_for_uri(uri)
                 if f.query_exists():
                     return uri
         except:
@@ -104,7 +105,7 @@ class AlbumArt(BaseArt, TagReader):
         # Folders with many albums, get_album_artwork_uri()
         if Lp().albums.get_uri_count(album.uri) > 1:
             return None
-        f = Gio.File.new_for_uri(album.uri)
+        f = Lio.File.new_for_uri(album.uri)
         infos = f.enumerate_children('standard::name',
                                      Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
                                      None)
@@ -125,7 +126,7 @@ class AlbumArt(BaseArt, TagReader):
         if album.is_web:
             return []
 
-        f = Gio.File.new_for_uri(album.uri)
+        f = Lio.File.new_for_uri(album.uri)
         infos = f.enumerate_children('standard::name',
                                      Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
                                      None)
@@ -153,7 +154,7 @@ class AlbumArt(BaseArt, TagReader):
 
         try:
             # Look in cache
-            f = Gio.File.new_for_path(cache_path_jpg)
+            f = Lio.File.new_for_path(cache_path_jpg)
             if f.query_exists():
                 pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(cache_path_jpg,
                                                                 size,
@@ -164,7 +165,7 @@ class AlbumArt(BaseArt, TagReader):
                     uri = self.get_album_artwork_uri(album)
                     data = None
                     if uri is not None:
-                        f = Gio.File.new_for_uri(uri)
+                        f = Lio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
                         ratio = self._respect_ratio(uri)
                         stream = Gio.MemoryInputStream.new_from_data(data,
@@ -188,7 +189,7 @@ class AlbumArt(BaseArt, TagReader):
                     uri = self.get_first_album_artwork(album)
                     # Look in album folder
                     if uri is not None:
-                        f = Gio.File.new_for_uri(uri)
+                        f = Lio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
                         ratio = self._respect_ratio(uri)
                         stream = Gio.MemoryInputStream.new_from_data(data,
@@ -240,10 +241,26 @@ class AlbumArt(BaseArt, TagReader):
             @param album id as int
         """
         try:
-            arturi = None
-            save_to_tags = Lp().settings.get_value('save-to-tags') and\
-                GLib.find_program_in_path("kid3-cli") is not None
             album = Album(album_id)
+            arturi = None
+            # Check portal for kid3-cli
+            can_set_cover = False
+            try:
+                bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+                proxy = Gio.DBusProxy.new_sync(
+                                            bus, Gio.DBusProxyFlags.NONE, None,
+                                            'org.gnome.Lollypop.Portal',
+                                            '/org/gnome/LollypopPortal',
+                                            'org.gnome.Lollypop.Portal', None)
+                can_set_cover = proxy.call_sync(
+                                               'CanSetCover', None,
+                                               Gio.DBusCallFlags.NO_AUTO_START,
+                                               500, None)[0]
+            except:
+                print("You are missing lollypop-portal: "
+                      "https://github.com/gnumdk/lollypop-portal")
+            save_to_tags = Lp().settings.get_value('save-to-tags') and\
+                can_set_cover and not album.is_web
 
             uri_count = Lp().albums.get_uri_count(album.uri)
             filename = self.get_album_cache_name(album) + ".jpg"
@@ -260,12 +277,12 @@ class AlbumArt(BaseArt, TagReader):
             elif uri_count > 1:
                 arturi = album.uri + "/" + filename
                 favorite_uri = album.uri + "/" + self.__favorite
-                favorite = Gio.File.new_for_uri(favorite_uri)
+                favorite = Lio.File.new_for_uri(favorite_uri)
                 if favorite.query_exists():
                     favorite.trash()
             else:
                 arturi = album.uri + "/" + self.__favorite
-            f = Gio.File.new_for_uri(arturi)
+            f = Lio.File.new_for_uri(arturi)
             # Update cover file if exists even if we have written to tags
             if not save_to_tags or f.query_exists():
                 stream = Gio.MemoryInputStream.new_from_data(data, None)
@@ -276,8 +293,8 @@ class AlbumArt(BaseArt, TagReader):
                                                                True,
                                                                None)
                 pixbuf.savev(store_path, "jpeg", ["quality"], ["90"])
-                dst = Gio.File.new_for_uri(arturi)
-                src = Gio.File.new_for_path(store_path)
+                dst = Lio.File.new_for_uri(arturi)
+                src = Lio.File.new_for_path(store_path)
                 src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
                 del pixbuf
                 self.clean_album_cache(album)
@@ -299,26 +316,39 @@ class AlbumArt(BaseArt, TagReader):
         """
         try:
             for uri in self.get_album_artworks(album):
-                f = Gio.File.new_for_uri(uri)
+                f = Lio.File.new_for_uri(uri)
                 try:
                     f.trash()
                 except:
                     f.delete(None)
-            if Lp().settings.get_value('save-to-tags') and\
-                    GLib.find_program_in_path("kid3-cli") is not None:
-                argv = ["kid3-cli", "-c", "select all", "-c",
-                        "set picture:'' ''"]
+            # Check portal for kid3-cli
+            can_set_cover = False
+            try:
+                bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+                proxy = Gio.DBusProxy.new_sync(
+                                            bus, Gio.DBusProxyFlags.NONE, None,
+                                            'org.gnome.Lollypop.Portal',
+                                            '/org/gnome/LollypopPortal',
+                                            'org.gnome.Lollypop.Portal', None)
+                can_set_cover = proxy.call_sync(
+                                               'CanSetCover', None,
+                                               Gio.DBusCallFlags.NO_AUTO_START,
+                                               500, None)[0]
+            except Exception as e:
+                print("You are missing lollypop-portal: "
+                      "https://github.com/gnumdk/lollypop-portal", e)
+            if Lp().settings.get_value('save-to-tags') and can_set_cover:
                 for uri in Lp().albums.get_track_uris(album.id, [], []):
                     try:
                         path = GLib.filename_from_uri(uri)[0]
-                        argv.append(path)
-                    except:  # Gvfs can't find path for uri
-                        pass
-                argv.append(None)
-                GLib.spawn_sync(None, argv, None,
-                                GLib.SpawnFlags.SEARCH_PATH, None)
+                        proxy.call_sync('SetCover',
+                                        GLib.Variant('(ss)', (path, "")),
+                                        Gio.DBusCallFlags.NO_AUTO_START,
+                                        500, None)
+                    except Exception as e:
+                        print("AlbumArt::remove_album_artwork2():", e)
         except Exception as e:
-            print("AlbumArt::remove_album_artwork():", e)
+            print("AlbumArt::remove_album_artwork3():", e)
 
     def clean_album_cache(self, album):
         """
@@ -327,7 +357,7 @@ class AlbumArt(BaseArt, TagReader):
         """
         cache_name = self.get_album_cache_name(album)
         try:
-            d = Gio.File.new_for_path(self._CACHE_PATH)
+            d = Lio.File.new_for_path(self._CACHE_PATH)
             infos = d.enumerate_children(
                 'standard::name',
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -348,7 +378,7 @@ class AlbumArt(BaseArt, TagReader):
             @param size as int
         """
         pixbuf = None
-        if uri.startswith('https:'):
+        if uri.startswith('http:') or uri.startswith('https:'):
             return
         try:
             info = self.get_info(uri)
@@ -399,23 +429,33 @@ class AlbumArt(BaseArt, TagReader):
                                                            ArtSize.MONSTER,
                                                            True,
                                                            None)
-        pixbuf.savev("/tmp/lollypop_cover_tags.jpg",
+        pixbuf.savev("%s/lollypop_cover_tags.jpg" % self._CACHE_PATH,
                      "jpeg", ["quality"], ["90"])
         del pixbuf
-        f = Gio.File.new_for_path("/tmp/lollypop_cover_tags.jpg")
+        f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
+                                  self._CACHE_PATH)
         if f.query_exists():
-            argv = ["kid3-cli", "-c", "select all", "-c",
-                    "set picture:'/tmp/lollypop_cover_tags.jpg' ''"]
             for uri in Lp().albums.get_track_uris(album.id, [], []):
                 try:
                     path = GLib.filename_from_uri(uri)[0]
-                    argv.append(path)
-                except:  # Gvfs can't find a path for uri
-                    pass
-            argv.append(None)
-            GLib.spawn_sync(None, argv, None,
-                            GLib.SpawnFlags.SEARCH_PATH, None)
-            f = Gio.File.new_for_path("/tmp/lollypop_cover_tags.jpg")
+                    bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+                    proxy = Gio.DBusProxy.new_sync(
+                                            bus, Gio.DBusProxyFlags.NONE, None,
+                                            'org.gnome.Lollypop.Portal',
+                                            '/org/gnome/LollypopPortal',
+                                            'org.gnome.Lollypop.Portal', None)
+                    proxy.call_sync('SetCover',
+                                    GLib.Variant(
+                                     '(ss)', (path,
+                                              "%s/lollypop_cover_tags.jpg" %
+                                              self._CACHE_PATH)),
+                                    Gio.DBusCallFlags.NO_AUTO_START,
+                                    500, None)
+                except Exception as e:
+                    print("You are missing lollypop-portal: "
+                          "https://github.com/gnumdk/lollypop-portal", e)
+            f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
+                                      self._CACHE_PATH)
             f.delete()
             self.clean_album_cache(album)
             GLib.idle_add(self.album_artwork_update, album.id)
