@@ -37,14 +37,14 @@ Lp = Gio.Application.get_default
 
 GOOGLE_API_ID = "015987506728554693370:waw3yqru59a"
 
+TAG_EDITORS = ['kid3-qt', 'exfalso', 'easytag', 'picard', 'puddletag']
+
 
 # Represent what to do on next track
 class NextContext:
     NONE = 0             # Continue playback
     REPEAT_TRACK = 1     # Repeat current track
-    STOP_TRACK = 2       # Stop after current track
-    STOP_ALBUM = 3       # Stop after current album
-    STOP_ALL = 4         # Stop
+    STOP = 2             # Stop after track/album/artist
 
 
 class DbPersistent:
@@ -64,7 +64,6 @@ class OpenLink:
 class PlayContext:
     genre_ids = {}
     artist_ids = {}
-    wanted = NextContext.NONE
 
 
 class GstPlayFlags:
