@@ -10,11 +10,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib, Gio
-
 import json
 
 from lollypop.utils import escape
+from lollypop.lio import Lio
 
 
 class WebJmg90:
@@ -29,7 +28,7 @@ class WebJmg90:
             @return content uri as str/None
         """
         try:
-            f = Gio.File.new_for_uri(uri)
+            f = Lio.File.new_for_uri(uri)
             (status, data, tag) = f.load_contents(None)
             if status:
                 return data.decode('utf-8')
@@ -76,12 +75,13 @@ class WebJmg90:
             artist = item.artists[0]
         unescaped = "%s %s" % (artist,
                                item.name)
-        search = GLib.uri_escape_string(unescaped,
-                                        None,
-                                        True)
+        search = Lio.uri_escape_string(unescaped,
+                                       '/?',
+                                       True)
         try:
-            f = Gio.File.new_for_uri("http://app.jgm90.com/cmapi/search/"
-                                     "%s/1/10" % search)
+            # Strip /? as API doesn't like it
+            f = Lio.File.new_for_uri("http://app.jgm90.com/cmapi/search/"
+                                     "%s/1/10" % search.strip('/?'))
             (status, data, tag) = f.load_contents(None)
             if status:
                 decode = json.loads(data.decode('utf-8'))
